import os

from pyramid.httpexceptions import HTTPTemporaryRedirect
from pyramid.static import static_view

from kinto.core.utils import json

from .views import admin_home_view

HERE = os.path.dirname(__file__)


def includeme(config):
    # Process settings to remove storage wording.

    # Read version from package.json
    package_json = json.load(open(os.path.join(HERE, "package.json")))
    admin_version = package_json["dependencies"]["kinto-admin"]

    # Expose capability.
    config.add_api_capability(
        "admin",
        version=admin_version,
        description="Serves the admin console.",
        url="https://github.com/Kinto/kinto-admin/",
    )

    config.add_route("admin_home", "/admin/")
    config.add_view(admin_home_view, route_name="admin_home")

    build_dir = static_view("kinto.plugins.admin:build", use_subpath=True)
    config.add_route("catchall_static", "/admin/*subpath")
    config.add_view(build_dir, route_name="catchall_static")

    # Setup redirect without trailing slash.
    def admin_redirect_view(request):
        raise HTTPTemporaryRedirect(request.path + "/")

    config.add_route("admin_redirect", "/admin")
    config.add_view(admin_redirect_view, route_name="admin_redirect")



"""
This module is a release hook for `zest.releaser <https://zestreleaser.readthedocs.io>`_
in order to build the Kinto Admin UI bundle just before it is packaged.

* See hooks in :file:`setup.cfg`
* `Documentation <http://zestreleaser.readthedocs.io/en/latest/entrypoints.html>`_
"""

import json
import os
import subprocess


def after_checkout(data):
    """
    During the ``release`` process, the current tag is checked out in a
    temporary folder. We build the Kinto Admin at this step, just before
    the files are gathered for the final Python package.

    .. note::

        The ``node_modules`` folder is excluded using :file:`MANIFEST.in`.
    """

    package_json_path = os.path.join("kinto", "plugins", "admin", "package.json")
    with open(package_json_path) as f:
        package_json = json.load(f)

    if package_json["version"] != package_json["dependencies"]["kinto-admin"]:
        raise ValueError("kinto-admin version mismatch in `package.json`")

    subprocess.run(["make", "build-kinto-admin"])
